@@ -6,6 +6,8 @@ from rich.console import Console
 from rich.table import Table
 from rich.progress import track
 from pathlib import Path
+from os import access, R_OK
+from os.path import isfile
 import argparse
 import time
 import json
@@ -36,7 +38,7 @@ from tempor.utils import (
     terraform_installed,
 )
 from tempor.workspaces import *
-from tempor.playbook import run_playbook
+from tempor.playbook import run_playbook, run_custom_playbook
 from tempor.ssh import check_sshkeys, install_ssh_keys
 
 
@@ -84,13 +86,16 @@ def get_args() -> (str, str, argparse.Namespace):
             metavar = "resources",
             help="Specify the hardware resources for the host image",
         )
-        prov_parser.add_argument("-s", "--setup", action="store_true", default=False, help="Create VPS'")
+        prov_parser.add_argument("-s", "--setup", action="store_true", default=False, help="Create a VPS")
         prov_parser.add_argument("-l", "--list", action="store_true", default=False, help="List Available VPS'")
         prov_parser.add_argument(
-            "-b", "--bare", action="store_true", default=False, help="Leave as a Bare Install"
+            "-m", "--minimal", action="store_true", default=False, help="Minimal Configuration (just configs)"
         )
         prov_parser.add_argument(
-            "-m", "--minimal", action="store_true", default=False, help="Minimal Configuration"
+            "-f", "--full", action="store_true", default=False, help="Full Configuration with hardening"
+        )
+        prov_parser.add_argument(
+            "-c", "--custom", type=str, default=False, help="Specify Ansible role for custom configuration (main.yml file)"
         )
         prov_parser.add_argument('-h', '--help', action='store_true')
 
@@ -100,6 +105,11 @@ def get_args() -> (str, str, argparse.Namespace):
     if args.teardown:
         return args
 
+    if args.custom:
+        file = args.custom
+        assert isfile(file) and access(file, R_OK), \
+       f"File {file} doesn't exist or isn't readable"
+
 
     # check options for this provider
     for p in cfg['providers']:
@@ -171,7 +181,7 @@ def get_args() -> (str, str, argparse.Namespace):
             parser.exit(0)
 
         # configure some easier options
-        if not args.setup and (args.bare or args.minimal):
+        if not args.setup and (args.full or args.minimal):
             args.setup = True
 
         if args.provider == 'aws':
@@ -382,9 +392,13 @@ def main(args: argparse.Namespace = None, override_teardown: bool = False) -> No
 
     save_hosts(args.provider, new_hosts)
 
-    if not args.bare:
-        playbook = 'minimal.yml' if args.minimal else 'main.yml'
-        run_playbook(playbook, args.user)
+    # Ansible configuration
+    if args.custom:
+        run_custom_playbook(args.custom, args.user)
+    elif args.full:
+        run_playbook('main.yml', args.user)
+    elif args.minimal:
+        run_playbook('minimal.yml', args.user)
 
     console.print("\nVPS' now available!\n", style="bold italic green")
     for host in new_hosts:
